@@ -13,45 +13,42 @@ var ANDROID_EVERGREEN_FIRST = 37
 var QUERY_OR = 1
 var QUERY_AND = 2
 
-function isVersionsMatch (versionA, versionB) {
+function isVersionsMatch(versionA, versionB) {
   return (versionA + '.').indexOf(versionB + '.') === 0
 }
 
-function isEolReleased (name) {
+function isEolReleased(name) {
   var version = name.slice(1)
   return jsReleases.some(function (i) {
     return isVersionsMatch(i.version, version)
   })
 }
 
-function normalize (versions) {
+function normalize(versions) {
   return versions.filter(function (version) {
     return typeof version === 'string'
   })
 }
 
-function normalizeElectron (version) {
+function normalizeElectron(version) {
   var versionToUse = version
   if (version.split('.').length === 3) {
-    versionToUse = version
-      .split('.')
-      .slice(0, -1)
-      .join('.')
+    versionToUse = version.split('.').slice(0, -1).join('.')
   }
   return versionToUse
 }
 
-function nameMapper (name) {
-  return function mapName (version) {
+function nameMapper(name) {
+  return function mapName(version) {
     return name + ' ' + version
   }
 }
 
-function getMajor (version) {
+function getMajor(version) {
   return parseInt(version.split('.')[0])
 }
 
-function getMajorVersions (released, number) {
+function getMajorVersions(released, number) {
   if (released.length === 0) return []
   var majorVersions = uniq(released.map(getMajor))
   var minimum = majorVersions[majorVersions.length - number]
@@ -66,7 +63,7 @@ function getMajorVersions (released, number) {
   return selected
 }
 
-function uniq (array) {
+function uniq(array) {
   var filtered = []
   for (var i = 0; i < array.length; i++) {
     if (filtered.indexOf(array[i]) === -1) filtered.push(array[i])
@@ -76,13 +73,13 @@ function uniq (array) {
 
 // Helpers
 
-function fillUsage (result, name, data) {
+function fillUsage(result, name, data) {
   for (var i in data) {
     result[name + ' ' + i] = data[i]
   }
 }
 
-function generateFilter (sign, version) {
+function generateFilter(sign, version) {
   version = parseFloat(version)
   if (sign === '>') {
     return function (v) {
@@ -103,7 +100,7 @@ function generateFilter (sign, version) {
   }
 }
 
-function generateSemverFilter (sign, version) {
+function generateSemverFilter(sign, version) {
   version = version.split('.').map(parseSimpleInt)
   version[1] = version[1] || 0
   version[2] = version[2] || 0
@@ -130,17 +127,17 @@ function generateSemverFilter (sign, version) {
   }
 }
 
-function parseSimpleInt (x) {
+function parseSimpleInt(x) {
   return parseInt(x)
 }
 
-function compare (a, b) {
+function compare(a, b) {
   if (a < b) return -1
   if (a > b) return +1
   return 0
 }
 
-function compareSemver (a, b) {
+function compareSemver(a, b) {
   return (
     compare(parseInt(a[0]), parseInt(b[0])) ||
     compare(parseInt(a[1] || '0'), parseInt(b[1] || '0')) ||
@@ -149,7 +146,7 @@ function compareSemver (a, b) {
 }
 
 // this follows the npm-like semver behavior
-function semverFilterLoose (operator, range) {
+function semverFilterLoose(operator, range) {
   range = range.split('.').map(parseSimpleInt)
   if (typeof range[1] === 'undefined') {
     range[1] = 'x'
@@ -162,8 +159,8 @@ function semverFilterLoose (operator, range) {
         version = version.split('.').map(parseSimpleInt)
         return compareSemverLoose(version, range) <= 0
       }
-    default:
     case '>=':
+    default:
       return function (version) {
         version = version.split('.').map(parseSimpleInt)
         return compareSemverLoose(version, range) >= 0
@@ -172,7 +169,7 @@ function semverFilterLoose (operator, range) {
 }
 
 // this follows the npm-like semver behavior
-function compareSemverLoose (version, range) {
+function compareSemverLoose(version, range) {
   if (version[0] !== range[0]) {
     return version[0] < range[0] ? -1 : +1
   }
@@ -185,7 +182,7 @@ function compareSemverLoose (version, range) {
   return 0
 }
 
-function resolveVersion (data, version) {
+function resolveVersion(data, version) {
   if (data.versions.indexOf(version) !== -1) {
     return version
   } else if (browserslist.versionAliases[data.name][version]) {
@@ -195,7 +192,7 @@ function resolveVersion (data, version) {
   }
 }
 
-function normalizeVersion (data, version) {
+function normalizeVersion(data, version) {
   var resolved = resolveVersion(data, version)
   if (resolved) {
     return resolved
@@ -206,19 +203,20 @@ function normalizeVersion (data, version) {
   }
 }
 
-function filterByYear (since, context) {
+function filterByYear(since, context) {
   since = since / 1000
   return Object.keys(agents).reduce(function (selected, name) {
     var data = byName(name, context)
     if (!data) return selected
     var versions = Object.keys(data.releaseDate).filter(function (v) {
-      return data.releaseDate[v] >= since
+      var date = data.releaseDate[v]
+      return date !== null && date >= since
     })
     return selected.concat(versions.map(nameMapper(data.name)))
   }, [])
 }
 
-function cloneData (data) {
+function cloneData(data) {
   return {
     name: data.name,
     versions: data.versions,
@@ -227,14 +225,14 @@ function cloneData (data) {
   }
 }
 
-function mapVersions (data, map) {
+function mapVersions(data, map) {
   data.versions = data.versions.map(function (i) {
     return map[i] || i
   })
   data.released = data.versions.map(function (i) {
     return map[i] || i
   })
-  var fixedDate = { }
+  var fixedDate = {}
   for (var i in data.releaseDate) {
     fixedDate[map[i] || i] = data.releaseDate[i]
   }
@@ -242,7 +240,7 @@ function mapVersions (data, map) {
   return data
 }
 
-function byName (name, context) {
+function byName(name, context) {
   name = name.toLowerCase()
   name = browserslist.aliases[name] || name
   if (context.mobileToDesktop && browserslist.desktopNames[name]) {
@@ -261,34 +259,38 @@ function byName (name, context) {
   return browserslist.data[name]
 }
 
-function normalizeAndroidVersions (androidVersions, chromeVersions) {
+function normalizeAndroidVersions(androidVersions, chromeVersions) {
   var firstEvergreen = ANDROID_EVERGREEN_FIRST
   var last = chromeVersions[chromeVersions.length - 1]
   return androidVersions
-    .filter(function (version) { return /^(?:[2-4]\.|[34]$)/.test(version) })
+    .filter(function (version) {
+      return /^(?:[2-4]\.|[34]$)/.test(version)
+    })
     .concat(chromeVersions.slice(firstEvergreen - last - 1))
 }
 
-function normalizeAndroidData (android, chrome) {
+function normalizeAndroidData(android, chrome) {
   android.released = normalizeAndroidVersions(android.released, chrome.released)
   android.versions = normalizeAndroidVersions(android.versions, chrome.versions)
   return android
 }
 
-function checkName (name, context) {
+function checkName(name, context) {
   var data = byName(name, context)
   if (!data) throw new BrowserslistError('Unknown browser ' + name)
   return data
 }
 
-function unknownQuery (query) {
+function unknownQuery(query) {
   return new BrowserslistError(
-    'Unknown browser query `' + query + '`. ' +
-    'Maybe you are using old Browserslist or made typo in query.'
+    'Unknown browser query `' +
+      query +
+      '`. ' +
+      'Maybe you are using old Browserslist or made typo in query.'
   )
 }
 
-function filterAndroid (list, versions, context) {
+function filterAndroid(list, versions, context) {
   if (context.mobileToDesktop) return list
   var released = browserslist.data.android.released
   var last = released[released.length - 1]
@@ -308,7 +310,7 @@ function filterAndroid (list, versions, context) {
  * the select function in `queries`.
  * @returns {string[]} A list of browsers
  */
-function resolve (queries, context) {
+function resolve(queries, context) {
   if (Array.isArray(queries)) {
     queries = flatten(queries.map(parse))
   } else {
@@ -323,7 +325,10 @@ function resolve (queries, context) {
       if (index === 0) {
         throw new BrowserslistError(
           'Write any browsers query (for instance, `defaults`) ' +
-          'before `' + selection + '`')
+            'before `' +
+            selection +
+            '`'
+        )
       }
       selection = selection.slice(4)
     }
@@ -356,7 +361,7 @@ function resolve (queries, context) {
           case QUERY_OR:
           default:
             if (isExclude) {
-              var filter = { }
+              var filter = {}
               array.forEach(function (j) {
                 filter[j] = true
               })
@@ -373,7 +378,7 @@ function resolve (queries, context) {
   }, [])
 }
 
-var cache = { }
+var cache = {}
 
 /**
  * Return array of browsers by selection queries.
@@ -392,6 +397,7 @@ var cache = { }
  *                                                     version in direct query.
  * @param {boolean} [opts.dangerousExtend] Disable security checks
  *                                         for extend query.
+ * @param {boolean} [opts.throwOnMissing] Throw error on missing env.
  * @param {boolean} [opts.mobileToDesktop] Alias mobile browsers to the desktop
  *                                         version when Can I Use doesn't have
  *                                         data about the specified version.
@@ -400,8 +406,8 @@ var cache = { }
  * @example
  * browserslist('IE >= 10, IE 8') //=> ['ie 11', 'ie 10', 'ie 8']
  */
-function browserslist (queries, opts) {
-  if (typeof opts === 'undefined') opts = { }
+function browserslist(queries, opts) {
+  if (typeof opts === 'undefined') opts = {}
 
   if (typeof opts.path === 'undefined') {
     opts.path = path.resolve ? path.resolve('.') : '.'
@@ -418,7 +424,8 @@ function browserslist (queries, opts) {
 
   if (!(typeof queries === 'string' || Array.isArray(queries))) {
     throw new BrowserslistError(
-      'Browser queries must be an array or string. Got ' + typeof queries + '.')
+      'Browser queries must be an array or string. Got ' + typeof queries + '.'
+    )
   }
 
   var context = {
@@ -432,7 +439,7 @@ function browserslist (queries, opts) {
   env.oldDataWarning(browserslist.data)
   var stats = env.getStat(opts, browserslist.data)
   if (stats) {
-    context.customUsage = { }
+    context.customUsage = {}
     for (var browser in stats) {
       fillUsage(context.customUsage, browser, stats[browser])
     }
@@ -461,7 +468,7 @@ function browserslist (queries, opts) {
   return result
 }
 
-function parse (queries) {
+function parse(queries) {
   var qs = []
   do {
     queries = doMatch(queries, qs)
@@ -469,7 +476,7 @@ function parse (queries) {
   return qs
 }
 
-function doMatch (string, qs) {
+function doMatch(string, qs) {
   var or = /^(?:,\s*|\s+or\s+)(.*)/i
   var and = /^\s+and\s+(.*)/i
 
@@ -488,7 +495,7 @@ function doMatch (string, qs) {
   })
 }
 
-function find (string, predicate) {
+function find(string, predicate) {
   for (var n = 1, max = string.length; n <= max; n++) {
     var parsed = string.substr(-n, n)
     if (predicate(parsed, n, max)) {
@@ -498,7 +505,7 @@ function find (string, predicate) {
   return ''
 }
 
-function flatten (array) {
+function flatten(array) {
   if (!Array.isArray(array)) return [array]
   return array.reduce(function (a, b) {
     return a.concat(flatten(b))
@@ -506,20 +513,15 @@ function flatten (array) {
 }
 
 // Will be filled by Can I Use data below
-browserslist.cache = { }
-browserslist.data = { }
+browserslist.cache = {}
+browserslist.data = {}
 browserslist.usage = {
-  global: { },
+  global: {},
   custom: null
 }
 
 // Default browsers query
-browserslist.defaults = [
-  '> 0.5%',
-  'last 2 versions',
-  'Firefox ESR',
-  'not dead'
-]
+browserslist.defaults = ['> 0.5%', 'last 2 versions', 'Firefox ESR', 'not dead']
 
 // Browser names aliases
 browserslist.aliases = {
@@ -548,7 +550,7 @@ browserslist.desktopNames = {
 }
 
 // Aliases to work with joined versions like `ios_saf 7.0-7.1`
-browserslist.versionAliases = { }
+browserslist.versionAliases = {}
 
 browserslist.clearCaches = env.clearCaches
 browserslist.parseConfig = env.parseConfig
@@ -597,7 +599,7 @@ browserslist.coverage = function (browsers, stats) {
     if ('dataByBrowser' in stats) {
       stats = stats.dataByBrowser
     }
-    data = { }
+    data = {}
     for (var name in stats) {
       for (var version in stats[name]) {
         data[name + ' ' + version] = stats[name][version]
@@ -614,6 +616,66 @@ browserslist.coverage = function (browsers, stats) {
   }, 0)
 }
 
+function nodeQuery(context, version) {
+  var nodeReleases = jsReleases.filter(function (i) {
+    return i.name === 'nodejs'
+  })
+  var matched = nodeReleases.filter(function (i) {
+    return isVersionsMatch(i.version, version)
+  })
+  if (matched.length === 0) {
+    if (context.ignoreUnknownVersions) {
+      return []
+    } else {
+      throw new BrowserslistError('Unknown version ' + version + ' of Node.js')
+    }
+  }
+  return ['node ' + matched[matched.length - 1].version]
+}
+
+function sinceQuery(context, year, month, date) {
+  year = parseInt(year)
+  month = parseInt(month || '01') - 1
+  date = parseInt(date || '01')
+  return filterByYear(Date.UTC(year, month, date, 0, 0, 0), context)
+}
+
+function coverQuery(context, coverage, statMode) {
+  coverage = parseFloat(coverage)
+  var usage = browserslist.usage.global
+  if (statMode) {
+    if (statMode.match(/^my\s+stats$/i)) {
+      if (!context.customUsage) {
+        throw new BrowserslistError('Custom usage statistics was not provided')
+      }
+      usage = context.customUsage
+    } else {
+      var place
+      if (statMode.length === 2) {
+        place = statMode.toUpperCase()
+      } else {
+        place = statMode.toLowerCase()
+      }
+      env.loadCountry(browserslist.usage, place, browserslist.data)
+      usage = browserslist.usage[place]
+    }
+  }
+  var versions = Object.keys(usage).sort(function (a, b) {
+    return usage[b] - usage[a]
+  })
+  var coveraged = 0
+  var result = []
+  var version
+  for (var i = 0; i < versions.length; i++) {
+    version = versions[i]
+    if (usage[version] === 0) break
+    coveraged += usage[version]
+    result.push(version)
+    if (coveraged >= coverage) break
+  }
+  return result
+}
+
 var QUERIES = [
   {
     regexp: /^last\s+(\d+)\s+major\s+versions?$/i,
@@ -669,9 +731,11 @@ var QUERIES = [
   {
     regexp: /^last\s+(\d+)\s+electron\s+versions?$/i,
     select: function (context, versions) {
-      return Object.keys(e2c).slice(-versions).map(function (i) {
-        return 'chrome ' + e2c[i]
-      })
+      return Object.keys(e2c)
+        .slice(-versions)
+        .map(function (i) {
+          return 'chrome ' + e2c[i]
+        })
     }
   },
   {
@@ -709,9 +773,11 @@ var QUERIES = [
     regexp: /^unreleased\s+(\w+)\s+versions?$/i,
     select: function (context, name) {
       var data = checkName(name, context)
-      return data.versions.filter(function (v) {
-        return data.released.indexOf(v) === -1
-      }).map(nameMapper(data.name))
+      return data.versions
+        .filter(function (v) {
+          return data.released.indexOf(v) === -1
+        })
+        .map(nameMapper(data.name))
     }
   },
   {
@@ -721,16 +787,19 @@ var QUERIES = [
     }
   },
   {
-    regexp: /^since (\d+)(?:-(\d+))?(?:-(\d+))?$/i,
-    select: function (context, year, month, date) {
-      year = parseInt(year)
-      month = parseInt(month || '01') - 1
-      date = parseInt(date || '01')
-      return filterByYear(Date.UTC(year, month, date, 0, 0, 0), context)
-    }
+    regexp: /^since (\d+)$/i,
+    select: sinceQuery
   },
   {
-    regexp: /^(>=?|<=?)\s*(\d*\.?\d+)%$/,
+    regexp: /^since (\d+)-(\d+)$/i,
+    select: sinceQuery
+  },
+  {
+    regexp: /^since (\d+)-(\d+)-(\d+)$/i,
+    select: sinceQuery
+  },
+  {
+    regexp: /^(>=?|<=?)\s*(\d+|\d+\.\d+|\.\d+)%$/,
     select: function (context, sign, popularity) {
       popularity = parseFloat(popularity)
       var usage = browserslist.usage.global
@@ -755,7 +824,7 @@ var QUERIES = [
     }
   },
   {
-    regexp: /^(>=?|<=?)\s*(\d*\.?\d+)%\s+in\s+my\s+stats$/,
+    regexp: /^(>=?|<=?)\s*(\d+|\d+\.\d+|\.\d+)%\s+in\s+my\s+stats$/,
     select: function (context, sign, popularity) {
       popularity = parseFloat(popularity)
       if (!context.customUsage) {
@@ -763,19 +832,24 @@ var QUERIES = [
       }
       var usage = context.customUsage
       return Object.keys(usage).reduce(function (result, version) {
+        var percentage = usage[version]
+        if (percentage == null) {
+          return result
+        }
+
         if (sign === '>') {
-          if (usage[version] > popularity) {
+          if (percentage > popularity) {
             result.push(version)
           }
         } else if (sign === '<') {
-          if (usage[version] < popularity) {
+          if (percentage < popularity) {
             result.push(version)
           }
         } else if (sign === '<=') {
-          if (usage[version] <= popularity) {
+          if (percentage <= popularity) {
             result.push(version)
           }
-        } else if (usage[version] >= popularity) {
+        } else if (percentage >= popularity) {
           result.push(version)
         }
         return result
@@ -783,12 +857,12 @@ var QUERIES = [
     }
   },
   {
-    regexp: /^(>=?|<=?)\s*(\d*\.?\d+)%\s+in\s+(\S+)\s+stats$/,
+    regexp: /^(>=?|<=?)\s*(\d+|\d+\.\d+|\.\d+)%\s+in\s+(\S+)\s+stats$/,
     select: function (context, sign, popularity, name) {
       popularity = parseFloat(popularity)
       var stats = env.loadStat(context, name, browserslist.data)
       if (stats) {
-        context.customUsage = { }
+        context.customUsage = {}
         for (var browser in stats) {
           fillUsage(context.customUsage, browser, stats[browser])
         }
@@ -798,19 +872,24 @@ var QUERIES = [
       }
       var usage = context.customUsage
       return Object.keys(usage).reduce(function (result, version) {
+        var percentage = usage[version]
+        if (percentage == null) {
+          return result
+        }
+
         if (sign === '>') {
-          if (usage[version] > popularity) {
+          if (percentage > popularity) {
             result.push(version)
           }
         } else if (sign === '<') {
-          if (usage[version] < popularity) {
+          if (percentage < popularity) {
             result.push(version)
           }
         } else if (sign === '<=') {
-          if (usage[version] <= popularity) {
+          if (percentage <= popularity) {
             result.push(version)
           }
-        } else if (usage[version] >= popularity) {
+        } else if (percentage >= popularity) {
           result.push(version)
         }
         return result
@@ -818,7 +897,7 @@ var QUERIES = [
     }
   },
   {
-    regexp: /^(>=?|<=?)\s*(\d*\.?\d+)%\s+in\s+((alt-)?\w\w)$/,
+    regexp: /^(>=?|<=?)\s*(\d+|\d+\.\d+|\.\d+)%\s+in\s+((alt-)?\w\w)$/,
     select: function (context, sign, popularity, place) {
       popularity = parseFloat(popularity)
       if (place.length === 2) {
@@ -829,19 +908,24 @@ var QUERIES = [
       env.loadCountry(browserslist.usage, place, browserslist.data)
       var usage = browserslist.usage[place]
       return Object.keys(usage).reduce(function (result, version) {
+        var percentage = usage[version]
+        if (percentage == null) {
+          return result
+        }
+
         if (sign === '>') {
-          if (usage[version] > popularity) {
+          if (percentage > popularity) {
             result.push(version)
           }
         } else if (sign === '<') {
-          if (usage[version] < popularity) {
+          if (percentage < popularity) {
             result.push(version)
           }
         } else if (sign === '<=') {
-          if (usage[version] <= popularity) {
+          if (percentage <= popularity) {
             result.push(version)
           }
-        } else if (usage[version] >= popularity) {
+        } else if (percentage >= popularity) {
           result.push(version)
         }
         return result
@@ -849,45 +933,12 @@ var QUERIES = [
     }
   },
   {
-    regexp: /^cover\s+(\d*\.?\d+)%(\s+in\s+(my\s+stats|(alt-)?\w\w))?$/,
-    select: function (context, coverage, statMode) {
-      coverage = parseFloat(coverage)
-      var usage = browserslist.usage.global
-      if (statMode) {
-        if (statMode.match(/^\s+in\s+my\s+stats$/)) {
-          if (!context.customUsage) {
-            throw new BrowserslistError(
-              'Custom usage statistics was not provided'
-            )
-          }
-          usage = context.customUsage
-        } else {
-          var match = statMode.match(/\s+in\s+((alt-)?\w\w)/)
-          var place = match[1]
-          if (place.length === 2) {
-            place = place.toUpperCase()
-          } else {
-            place = place.toLowerCase()
-          }
-          env.loadCountry(browserslist.usage, place, browserslist.data)
-          usage = browserslist.usage[place]
-        }
-      }
-      var versions = Object.keys(usage).sort(function (a, b) {
-        return usage[b] - usage[a]
-      })
-      var coveraged = 0
-      var result = []
-      var version
-      for (var i = 0; i <= versions.length; i++) {
-        version = versions[i]
-        if (usage[version] === 0) break
-        coveraged += usage[version]
-        result.push(version)
-        if (coveraged >= coverage) break
-      }
-      return result
-    }
+    regexp: /^cover\s+(\d+|\d+\.\d+|\.\d+)%$/i,
+    select: coverQuery
+  },
+  {
+    regexp: /^cover\s+(\d+|\d+\.\d+|\.\d+)%\s+in\s+(my\s+stats|(alt-)?\w\w)$/i,
+    select: coverQuery
   },
   {
     regexp: /^supports\s+([\w-]+)$/,
@@ -916,31 +967,26 @@ var QUERIES = [
       }
       from = parseFloat(from)
       to = parseFloat(to)
-      return Object.keys(e2c).filter(function (i) {
-        var parsed = parseFloat(i)
-        return parsed >= from && parsed <= to
-      }).map(function (i) {
-        return 'chrome ' + e2c[i]
-      })
+      return Object.keys(e2c)
+        .filter(function (i) {
+          var parsed = parseFloat(i)
+          return parsed >= from && parsed <= to
+        })
+        .map(function (i) {
+          return 'chrome ' + e2c[i]
+        })
     }
   },
   {
     regexp: /^node\s+([\d.]+)\s*-\s*([\d.]+)$/i,
     select: function (context, from, to) {
-      var nodeVersions = jsReleases.filter(function (i) {
-        return i.name === 'nodejs'
-      }).map(function (i) {
-        return i.version
-      })
-      var semverRegExp = /^(0|[1-9]\d*)(\.(0|[1-9]\d*)){0,2}$/
-      if (!semverRegExp.test(from)) {
-        throw new BrowserslistError(
-          'Unknown version ' + from + ' of Node.js')
-      }
-      if (!semverRegExp.test(to)) {
-        throw new BrowserslistError(
-          'Unknown version ' + to + ' of Node.js')
-      }
+      var nodeVersions = jsReleases
+        .filter(function (i) {
+          return i.name === 'nodejs'
+        })
+        .map(function (i) {
+          return i.version
+        })
       return nodeVersions
         .filter(semverFilterLoose('>=', from))
         .filter(semverFilterLoose('<=', to))
@@ -955,7 +1001,7 @@ var QUERIES = [
       var data = checkName(name, context)
       from = parseFloat(normalizeVersion(data, from) || from)
       to = parseFloat(normalizeVersion(data, to) || to)
-      function filter (v) {
+      function filter(v) {
         var parsed = parseFloat(v)
         return parsed >= from && parsed <= to
       }
@@ -976,11 +1022,13 @@ var QUERIES = [
   {
     regexp: /^node\s*(>=?|<=?)\s*([\d.]+)$/i,
     select: function (context, sign, version) {
-      var nodeVersions = jsReleases.filter(function (i) {
-        return i.name === 'nodejs'
-      }).map(function (i) {
-        return i.version
-      })
+      var nodeVersions = jsReleases
+        .filter(function (i) {
+          return i.name === 'nodejs'
+        })
+        .map(function (i) {
+          return i.version
+        })
       return nodeVersions
         .filter(generateSemverFilter(sign, version))
         .map(function (v) {
@@ -1006,7 +1054,7 @@ var QUERIES = [
   {
     regexp: /^(firefox|ff|fx)\s+esr$/i,
     select: function () {
-      return ['firefox 78']
+      return ['firefox 91']
     }
   },
   {
@@ -1022,30 +1070,23 @@ var QUERIES = [
       var chrome = e2c[versionToUse]
       if (!chrome) {
         throw new BrowserslistError(
-          'Unknown version ' + version + ' of electron')
+          'Unknown version ' + version + ' of electron'
+        )
       }
       return ['chrome ' + chrome]
     }
   },
   {
-    regexp: /^node\s+(\d+(\.\d+)?(\.\d+)?)$/i,
-    select: function (context, version) {
-      var nodeReleases = jsReleases.filter(function (i) {
-        return i.name === 'nodejs'
-      })
-      var matched = nodeReleases.filter(function (i) {
-        return isVersionsMatch(i.version, version)
-      })
-      if (matched.length === 0) {
-        if (context.ignoreUnknownVersions) {
-          return []
-        } else {
-          throw new BrowserslistError(
-            'Unknown version ' + version + ' of Node.js')
-        }
-      }
-      return ['node ' + matched[matched.length - 1].version]
-    }
+    regexp: /^node\s+(\d+)$/i,
+    select: nodeQuery
+  },
+  {
+    regexp: /^node\s+(\d+\.\d+)$/i,
+    select: nodeQuery
+  },
+  {
+    regexp: /^node\s+(\d+\.\d+\.\d+)$/i,
+    select: nodeQuery
   },
   {
     regexp: /^current\s+node$/i,
@@ -1057,13 +1098,17 @@ var QUERIES = [
     regexp: /^maintained\s+node\s+versions$/i,
     select: function (context) {
       var now = Date.now()
-      var queries = Object.keys(jsEOL).filter(function (key) {
-        return now < Date.parse(jsEOL[key].end) &&
-          now > Date.parse(jsEOL[key].start) &&
-          isEolReleased(key)
-      }).map(function (key) {
-        return 'node ' + key.slice(1)
-      })
+      var queries = Object.keys(jsEOL)
+        .filter(function (key) {
+          return (
+            now < Date.parse(jsEOL[key].end) &&
+            now > Date.parse(jsEOL[key].start) &&
+            isEolReleased(key)
+          )
+        })
+        .map(function (key) {
+          return 'node ' + key.slice(1)
+        })
       return resolve(queries, context)
     }
   },
@@ -1100,7 +1145,8 @@ var QUERIES = [
           return []
         } else {
           throw new BrowserslistError(
-            'Unknown version ' + version + ' of ' + name)
+            'Unknown version ' + version + ' of ' + name
+          )
         }
       }
       return [data.name + ' ' + version]
@@ -1142,17 +1188,18 @@ var QUERIES = [
     select: function (context, name) {
       if (byName(name, context)) {
         throw new BrowserslistError(
-          'Specify versions in Browserslist query for browser ' + name)
+          'Specify versions in Browserslist query for browser ' + name
+        )
       } else {
         throw unknownQuery(name)
       }
     }
   }
-];
+]
 
 // Get and convert Can I Use data
 
-(function () {
+;(function () {
   for (var name in agents) {
     var browser = agents[name]
     browserslist.data[name] = {
@@ -1163,7 +1210,7 @@ var QUERIES = [
     }
     fillUsage(browserslist.usage.global, name, browser.usage_global)
 
-    browserslist.versionAliases[name] = { }
+    browserslist.versionAliases[name] = {}
     for (var i = 0; i < browser.versions.length; i++) {
       var full = browser.versions[i]
       if (!full) continue
@@ -1178,6 +1225,6 @@ var QUERIES = [
   }
 
   browserslist.versionAliases.op_mob['59'] = '58'
-}())
+})()
 
 module.exports = browserslist
